# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T05:08:21+00:00

from __future__ import annotations

from typing import Any, List, Optional

from pydantic import BaseModel


class Stream(BaseModel):
    id: str
    type: str
    video_codec: Optional[str] = None
    video_codec_level: Optional[str] = None
    video_bitrate: Optional[str] = None
    video_bit_depth: Optional[str] = None
    video_chroma_subsampling: Optional[str] = None
    video_color_primaries: Optional[str] = None
    video_color_range: Optional[str] = None
    video_color_space: Optional[str] = None
    video_color_trc: Optional[str] = None
    video_frame_rate: Optional[str] = None
    video_ref_frames: Optional[str] = None
    video_height: Optional[str] = None
    video_width: Optional[str] = None
    video_language: Optional[str] = None
    video_language_code: Optional[str] = None
    video_profile: Optional[str] = None
    video_scan_type: Optional[str] = None
    selected: int
    audio_codec: Optional[str] = None
    audio_bitrate: Optional[str] = None
    audio_bitrate_mode: Optional[str] = None
    audio_channels: Optional[str] = None
    audio_channel_layout: Optional[str] = None
    audio_sample_rate: Optional[str] = None
    audio_language: Optional[str] = None
    audio_language_code: Optional[str] = None
    audio_profile: Optional[str] = None
    subtitle_codec: Optional[str] = None
    subtitle_container: Optional[str] = None
    subtitle_format: Optional[str] = None
    subtitle_forced: Optional[int] = None
    subtitle_location: Optional[str] = None
    subtitle_language: Optional[str] = None
    subtitle_language_code: Optional[str] = None


class Part(BaseModel):
    id: str
    file: str
    file_size: str
    indexes: int
    streams: List[Stream]
    selected: int


class MediaInfoItem(BaseModel):
    id: str
    container: str
    bitrate: str
    height: str
    width: str
    aspect_ratio: str
    video_codec: str
    video_resolution: str
    video_full_resolution: str
    video_framerate: str
    video_profile: str
    audio_codec: str
    audio_channels: str
    audio_channel_layout: str
    audio_profile: str
    optimized_version: int
    channel_call_sign: str
    channel_identifier: str
    channel_thumb: str
    parts: List[Part]


class MovieItem(BaseModel):
    media_type: str
    section_id: str
    library_name: str
    rating_key: str
    parent_rating_key: str
    grandparent_rating_key: str
    title: str
    parent_title: str
    grandparent_title: str
    original_title: str
    sort_title: str
    media_index: str
    parent_media_index: str
    studio: str
    content_rating: str
    summary: str
    tagline: str
    rating: str
    rating_image: str
    audience_rating: str
    audience_rating_image: str
    user_rating: str
    duration: str
    year: str
    thumb: str
    parent_thumb: str
    grandparent_thumb: str
    art: str
    banner: str
    originally_available_at: str
    added_at: str
    updated_at: str
    last_viewed_at: str
    guid: str
    parent_guid: str
    grandparent_guid: str
    directors: List
    writers: List
    actors: List
    genres: List
    labels: List
    collections: List
    guids: List
    full_title: str
    children_count: int
    live: int
    media_info: List[MediaInfoItem]


class ShowItem(BaseModel):
    media_type: str
    section_id: str
    library_name: str
    rating_key: str
    parent_rating_key: str
    grandparent_rating_key: str
    title: str
    parent_title: str
    grandparent_title: str
    original_title: str
    sort_title: str
    media_index: str
    parent_media_index: str
    studio: str
    content_rating: str
    summary: str
    tagline: str
    rating: str
    rating_image: str
    audience_rating: str
    audience_rating_image: str
    user_rating: str
    duration: str
    year: str
    thumb: str
    parent_thumb: str
    grandparent_thumb: str
    art: str
    banner: str
    originally_available_at: str
    added_at: str
    updated_at: str
    last_viewed_at: str
    guid: str
    parent_guid: str
    grandparent_guid: str
    directors: List
    writers: List
    actors: List[str]
    genres: List[str]
    labels: List
    collections: List
    guids: List
    full_title: str
    children_count: int
    live: int
    media_info: List


class SeasonItem(BaseModel):
    media_type: str
    section_id: str
    library_name: str
    rating_key: str
    parent_rating_key: str
    grandparent_rating_key: str
    title: str
    parent_title: str
    grandparent_title: str
    original_title: str
    sort_title: str
    media_index: str
    parent_media_index: str
    studio: str
    content_rating: str
    summary: str
    tagline: str
    rating: str
    rating_image: str
    audience_rating: str
    audience_rating_image: str
    user_rating: str
    duration: str
    year: str
    thumb: str
    parent_thumb: str
    grandparent_thumb: str
    art: str
    banner: str
    originally_available_at: str
    added_at: str
    updated_at: str
    last_viewed_at: str
    guid: str
    parent_guid: str
    grandparent_guid: str
    directors: List
    writers: List
    actors: List[str]
    genres: List[str]
    labels: List
    collections: List
    guids: List
    full_title: str
    children_count: int
    live: int
    media_info: List


class EpisodeItem(BaseModel):
    media_type: str
    section_id: str
    library_name: str
    rating_key: str
    parent_rating_key: str
    grandparent_rating_key: str
    title: str
    parent_title: str
    grandparent_title: str
    original_title: str
    sort_title: str
    media_index: str
    parent_media_index: str
    studio: str
    content_rating: str
    summary: str
    tagline: str
    rating: str
    rating_image: str
    audience_rating: str
    audience_rating_image: str
    user_rating: str
    duration: str
    year: str
    thumb: str
    parent_thumb: str
    grandparent_thumb: str
    art: str
    banner: str
    originally_available_at: str
    added_at: str
    updated_at: str
    last_viewed_at: str
    guid: str
    parent_guid: str
    grandparent_guid: str
    directors: List[str]
    writers: List[str]
    actors: List[str]
    genres: List[str]
    labels: List
    collections: List
    guids: List
    full_title: str
    children_count: int
    live: int
    media_info: List[MediaInfoItem]


class ResultsList(BaseModel):
    movie: List[MovieItem]
    show: List[ShowItem]
    season: List[SeasonItem]
    episode: List[EpisodeItem]
    artist: List
    album: List
    track: List
    collection: List


class Data(BaseModel):
    results_count: int
    results_list: ResultsList


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T03:57:17+00:00

from __future__ import annotations

from typing import Any

from pydantic import BaseModel


class Data(BaseModel):
    update_available: bool
    platform: str
    release_date: int
    version: str
    requirements: str
    extra_info: str
    changelog_added: str
    changelog_fixed: str
    label: str
    distro: str
    distro_build: str
    download_url: str


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T03:51:24+00:00

from __future__ import annotations

from typing import Any, List, Optional

from pydantic import BaseModel


class Data(BaseModel):
    section_id: int
    section_name: str
    section_type: str
    agent: Optional[str]


class Response(BaseModel):
    result: str
    message: Any
    data: List[Data]


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T05:06:32+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Net(BaseModel):
    cidr: str
    name: str
    handle: str
    range: str
    description: str
    country: str
    state: str
    city: str
    address: str
    postal_code: str
    emails: List[str]
    created: str
    updated: str


class Data(BaseModel):
    host: str
    nets: List[Net]


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T05:07:40+00:00

from __future__ import annotations

from pydantic import BaseModel


class Data(BaseModel):
    server_id: str
    pms_name: str
    pms_version: str
    pms_platform: str
    pms_ip: str
    pms_port: int
    pms_ssl: int
    pms_is_remote: int
    pms_is_cloud: int
    pms_url: str
    pms_url_manual: int
    pms_identifier: str
    pms_plexpass: int
    tautulli_install_type: str
    tautulli_version: str
    tautulli_branch: str
    tautulli_commit: str
    tautulli_platform: str
    tautulli_platform_release: str
    tautulli_platform_version: str
    tautulli_platform_linux_distro: str
    tautulli_platform_device_name: str
    tautulli_python_version: str


class Response(BaseModel):
    result: str
    message: str
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:22:54+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    name: str
    machine_identifier: str
    host: str
    port: str
    version: str


class Response(BaseModel):
    result: str
    message: Any
    data: List[Datum]


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:54:28+00:00

from __future__ import annotations

from typing import Any

from pydantic import BaseModel


class Data(BaseModel):
    bitrate: int
    video_full_resolution: str
    optimized_version: str
    optimized_version_profile: str
    optimized_version_title: str
    synced_version: str
    synced_version_profile: str
    container: str
    video_codec: str
    video_bitrate: int
    video_width: int
    video_height: int
    video_framerate: str
    video_dynamic_range: str
    aspect_ratio: str
    audio_codec: str
    audio_bitrate: int
    audio_channels: int
    subtitle_codec: str
    stream_bitrate: int
    stream_video_full_resolution: str
    quality_profile: str
    stream_container_decision: str
    stream_container: str
    stream_video_decision: str
    stream_video_codec: str
    stream_video_bitrate: int
    stream_video_width: int
    stream_video_height: int
    stream_video_framerate: str
    stream_video_dynamic_range: str
    stream_audio_decision: str
    stream_audio_codec: str
    stream_audio_bitrate: int
    stream_audio_channels: int
    subtitles: str
    stream_subtitle_decision: str
    stream_subtitle_codec: str
    transcode_hw_decoding: str
    transcode_hw_encoding: str
    video_decision: str
    audio_decision: str
    media_type: str
    title: str
    grandparent_title: str
    original_title: str
    current_session: int
    pre_tautulli: str


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:23:37+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class IFTTT(BaseModel):
    ifttt_on_stop: bool
    ifttt_on_pause: bool
    ifttt_key: str
    ifttt_on_concurrent: bool
    ifttt_on_created: bool
    ifttt_on_buffer: bool
    ifttt_enabled: bool
    ifttt_on_pmsupdate: bool
    ifttt_on_newdevice: bool
    ifttt_on_intdown: bool
    ifttt_on_extup: bool
    ifttt_on_intup: bool
    ifttt_on_resume: bool
    ifttt_on_watched: bool
    ifttt_event: str
    ifttt_on_extdown: bool
    ifttt_on_play: bool


class Growl(BaseModel):
    growl_enabled: bool
    growl_on_play: bool
    growl_on_stop: bool
    growl_on_buffer: bool
    growl_on_pause: bool
    growl_on_intdown: bool
    growl_host: str
    growl_on_extup: bool
    growl_on_newdevice: bool
    growl_on_pmsupdate: bool
    growl_password: str
    growl_on_resume: bool
    growl_on_created: bool
    growl_on_concurrent: bool
    growl_on_watched: bool
    growl_on_intup: bool
    growl_on_extdown: bool


class PMS(BaseModel):
    pms_use_bif: bool
    pms_uuid: str
    pms_url: str
    pms_update_channel: str
    pms_update_distro: str
    pms_name: str
    pms_logs_folder: str
    pms_plexpass: int
    pms_token: str
    pms_port: int
    pms_is_remote: int
    pms_identifier: str
    pms_ssl: int
    pms_version: str
    pms_update_distro_build: str
    pms_ip: str
    pms_logs_line_cap: str
    pms_platform: str
    pms_url_manual: int
    pms_web_url: str
    pms_is_cloud: int
    pms_url_override: str


class Monitoring(BaseModel):
    notify_upload_posters: str
    movie_notify_enable: bool
    notify_on_resume_body_text: str
    notify_on_pmsupdate_body_text: str
    refresh_libraries_on_startup: bool
    session_db_write_attempts: str
    notify_on_created_body_text: str
    buffer_wait: str
    notify_on_intup_subject_text: str
    notify_recently_added_grandparent: bool
    notify_on_newdevice_subject_text: str
    notify_on_extup_subject_text: str
    notify_on_watched_subject_text: str
    notify_on_pause_subject_text: str
    notify_on_extup_body_text: str
    notify_on_watched_body_text: str
    music_notify_on_pause: bool
    notify_on_start_body_text: str
    notify_on_pause_body_text: str
    notify_on_buffer_body_text: str
    music_notify_on_stop: bool
    tv_notify_on_stop: bool
    notify_on_stop_body_text: str
    notify_on_created_subject_text: str
    notify_on_extdown_body_text: str
    notify_scripts_args_text: str
    music_logging_enable: bool
    movie_notify_on_stop: bool
    notify_watched_percent: str
    notify_on_concurrent_subject_text: str
    notify_on_concurrent_body_text: str
    tv_logging_enable: bool
    tv_notify_enable: bool
    notify_recently_added_delay: str
    notify_on_intdown_body_text: str
    logging_ignore_interval: str
    notify_on_newdevice_body_text: str
    refresh_users_interval: str
    monitoring_use_websocket: bool
    monitor_pms_updates: bool
    notify_on_start_subject_text: str
    notify_recently_added: bool
    notify_on_pmsupdate_subject_text: str
    music_notify_enable: bool
    movie_notify_on_start: bool
    notify_concurrent_by_ip: bool
    refresh_users_on_startup: bool
    buffer_threshold: str
    notify_on_extdown_subject_text: str
    refresh_libraries_interval: str
    tv_notify_on_start: bool
    video_logging_enable: bool
    notify_on_resume_subject_text: str
    notify_concurrent_threshold: str
    notify_on_stop_subject_text: str
    movie_notify_on_pause: bool
    notify_consecutive: bool
    movie_logging_enable: bool
    notify_on_intup_body_text: str
    notify_on_intdown_subject_text: str
    music_notify_on_start: bool
    tv_notify_on_pause: bool
    monitor_remote_access: bool
    imgur_client_id: str
    monitoring_interval: str
    notify_on_buffer_subject_text: str
    tv_watched_percent: str
    notify_group_recently_added_grandparent: bool
    notify_recently_added_upgrade: bool
    notify_group_recently_added: bool
    notify_group_recently_added_parent: bool
    movie_watched_percent: str
    music_watched_percent: str
    notify_continued_session_threshold: str
    notify_remote_access_threshold: str
    notify_new_device_initial_only: bool


class GetFileSizesHold(BaseModel):
    section_ids: List
    rating_keys: List


class General(BaseModel):
    week_start_monday: bool
    git_token: str
    home_stats_cards: List[str]
    backup_interval: str
    graph_days: str
    graph_type: str
    get_file_sizes: bool
    http_basic_auth: bool
    api_sql: bool
    http_root: str
    http_proxy: bool
    freeze_db: bool
    ip_logging_enable: bool
    launch_browser: bool
    http_username: str
    https_create_cert: bool
    do_not_override_git_branch: bool
    home_stats_length: str
    http_host: str
    first_run_complete: bool
    enable_https: bool
    check_github: bool
    api_enabled: bool
    git_path: str
    update_labels: bool
    config_version: str
    check_github_interval: str
    https_ip: str
    group_history_tables: bool
    https_domain: str
    graph_tab: str
    geoip_db: str
    http_password: str
    home_stats_count: str
    backup_dir: str
    git_user: str
    interface: str
    cache_images: bool
    log_blacklist: bool
    graph_months: str
    cleanup_files: bool
    check_github_on_startup: bool
    http_port: str
    log_dir: str
    update_db_interval: str
    allow_guest_access: bool
    time_format: str
    cache_dir: str
    home_sections: List[str]
    backup_days: str
    https_cert: str
    api_key: str
    update_section_ids: bool
    date_format: str
    home_stats_type: bool
    http_environment: str
    history_table_activity: bool
    https_key: str
    http_hash_password: bool
    home_library_cards: List[str]
    http_hashed_password: bool
    git_branch: str
    anon_redirect: str
    http_plex_admin: bool
    update_show_changelog: int
    show_advanced_settings: bool
    git_remote: str
    https_cert_chain: str
    git_repo: str
    home_stats_recently_added_count: str
    themoviedb_apikey: str
    tvmaze_lookup: bool
    update_notifiers_db: bool
    themoviedb_lookup: bool
    plexpy_auto_update: bool
    update_libraries_db_notify: bool
    home_refresh_interval: str
    http_base_url: str
    win_sys_tray: bool
    musicbrainz_lookup: bool
    geoip_db_update_days: str
    maxmind_license_key: str
    geoip_db_installed: bool
    launch_startup: bool
    sys_tray_icon: bool
    export_dir: str
    http_rate_limit_attempts: str
    http_rate_limit_attempts_interval: str
    http_rate_limit_lockout_time: str
    get_file_sizes_hold: GetFileSizesHold
    interface_list: List[str]


class Slack(BaseModel):
    slack_on_stop: bool
    slack_icon_emoji: str
    slack_on_watched: bool
    slack_on_extup: bool
    slack_on_resume: bool
    slack_hook: str
    slack_incl_subject: bool
    slack_on_pmsupdate: bool
    slack_channel: str
    slack_on_buffer: bool
    slack_on_extdown: bool
    slack_username: str
    slack_incl_pmslink: bool
    slack_enabled: bool
    slack_incl_poster: bool
    slack_on_pause: bool
    slack_on_concurrent: bool
    slack_on_intup: bool
    slack_on_intdown: bool
    slack_on_play: bool
    slack_on_created: bool
    slack_on_newdevice: bool


class Boxcar(BaseModel):
    boxcar_sound: str
    boxcar_on_newdevice: bool
    boxcar_on_watched: bool
    boxcar_on_buffer: bool
    boxcar_on_stop: bool
    boxcar_on_extdown: bool
    boxcar_on_pmsupdate: bool
    boxcar_on_intdown: bool
    boxcar_on_pause: bool
    boxcar_on_play: bool
    boxcar_on_created: bool
    boxcar_on_intup: bool
    boxcar_on_resume: bool
    boxcar_on_concurrent: bool
    boxcar_enabled: bool
    boxcar_on_extup: bool
    boxcar_token: str


class PushBullet(BaseModel):
    pushbullet_on_play: bool
    pushbullet_channel_tag: str
    pushbullet_on_buffer: bool
    pushbullet_apikey: str
    pushbullet_on_resume: bool
    pushbullet_on_concurrent: bool
    pushbullet_on_created: bool
    pushbullet_on_pause: bool
    pushbullet_on_extdown: bool
    pushbullet_on_stop: bool
    pushbullet_on_extup: bool
    pushbullet_on_pmsupdate: bool
    pushbullet_enabled: bool
    pushbullet_on_watched: bool
    pushbullet_on_intdown: bool
    pushbullet_deviceid: str
    pushbullet_on_intup: bool
    pushbullet_on_newdevice: bool


class Scripts(BaseModel):
    scripts_on_newdevice: bool
    scripts_on_stop: bool
    scripts_on_intdown_script: str
    scripts_on_newdevice_script: str
    scripts_folder: str
    scripts_on_pmsupdate: bool
    scripts_on_buffer: bool
    scripts_on_concurrent: bool
    scripts_on_intup_script: str
    scripts_on_intdown: bool
    scripts_on_resume: bool
    scripts_on_extdown_script: str
    scripts_on_extup: bool
    scripts_on_play_script: str
    scripts_on_created_script: str
    scripts_on_pmsupdate_script: str
    scripts_on_resume_script: str
    scripts_on_stop_script: str
    scripts_on_watched_script: str
    scripts_enabled: bool
    scripts_on_extup_script: str
    scripts_on_extdown: bool
    scripts_on_created: bool
    scripts_on_concurrent_script: str
    scripts_on_pause_script: str
    scripts_on_pause: bool
    scripts_on_intup: bool
    scripts_timeout: str
    scripts_on_watched: bool
    scripts_on_buffer_script: str
    scripts_on_play: bool


class NMA(BaseModel):
    nma_on_pmsupdate: bool
    nma_priority: bool
    nma_on_intdown: bool
    nma_on_buffer: bool
    nma_on_play: bool
    nma_on_newdevice: bool
    nma_on_resume: bool
    nma_on_concurrent: bool
    nma_on_watched: bool
    nma_apikey: str
    nma_on_intup: bool
    nma_on_stop: bool
    nma_on_created: bool
    nma_on_pause: bool
    nma_enabled: bool
    nma_on_extdown: bool
    nma_on_extup: bool


class Hipchat(BaseModel):
    hipchat_emoticon: str
    hipchat_incl_subject: bool
    hipchat_on_extdown: bool
    hipchat_on_intup: bool
    hipchat_enabled: bool
    hipchat_on_created: bool
    hipchat_on_newdevice: bool
    hipchat_on_play: bool
    hipchat_on_resume: bool
    hipchat_on_buffer: bool
    hipchat_incl_poster: bool
    hipchat_on_watched: bool
    hipchat_color: str
    hipchat_on_concurrent: bool
    hipchat_url: str
    hipchat_on_pmsupdate: bool
    hipchat_on_extup: bool
    hipchat_incl_pmslink: bool
    hipchat_on_pause: bool
    hipchat_on_intdown: bool
    hipchat_on_stop: bool


class Pushalot(BaseModel):
    pushalot_apikey: str
    pushalot_on_pmsupdate: bool
    pushalot_enabled: bool
    pushalot_on_extdown: bool
    pushalot_on_created: bool
    pushalot_on_pause: bool
    pushalot_on_stop: bool
    pushalot_on_buffer: bool
    pushalot_on_intup: bool
    pushalot_on_newdevice: bool
    pushalot_on_concurrent: bool
    pushalot_on_watched: bool
    pushalot_on_play: bool
    pushalot_on_extup: bool
    pushalot_on_intdown: bool
    pushalot_on_resume: bool


class Prowl(BaseModel):
    prowl_on_created: bool
    prowl_on_play: bool
    prowl_on_extdown: bool
    prowl_on_pause: bool
    prowl_on_intdown: bool
    prowl_on_intup: bool
    prowl_enabled: bool
    prowl_priority: bool
    prowl_on_pmsupdate: bool
    prowl_on_newdevice: bool
    prowl_on_extup: bool
    prowl_on_watched: bool
    prowl_on_buffer: bool
    prowl_on_resume: bool
    prowl_on_stop: bool
    prowl_on_concurrent: bool
    prowl_keys: str


class Advanced(BaseModel):
    verify_ssl_cert: bool
    journal_mode: str
    pms_timeout: str
    cache_sizemb: str
    session_db_write_attempts: str
    system_analytics: bool
    notification_threads: str
    remote_access_ping_threshold: str
    websocket_connection_timeout: str
    config_version: str
    metadata_cache_seconds: str
    websocket_connection_attempts: str
    jwt_secret: str
    websocket_monitor_ping_pong: bool
    synchronous_mode: str
    pms_update_check_interval: str
    jwt_update_secret: bool
    verbose_logs: bool
    add_live_tv_library: bool
    remote_access_ping_interval: str
    check_github_cache_seconds: str
    export_threads: str


class Facebook(BaseModel):
    facebook_app_secret: str
    facebook_on_stop: bool
    facebook_token: str
    facebook_on_buffer: bool
    facebook_on_play: bool
    facebook_enabled: bool
    facebook_on_intup: bool
    facebook_incl_poster: bool
    facebook_on_pmsupdate: bool
    facebook_on_intdown: bool
    facebook_on_extup: bool
    facebook_on_resume: bool
    facebook_on_concurrent: bool
    facebook_on_extdown: bool
    facebook_group: str
    facebook_on_pause: bool
    facebook_app_id: str
    facebook_incl_pmslink: bool
    facebook_on_newdevice: bool
    facebook_on_watched: bool
    facebook_redirect_uri: str
    facebook_incl_subject: bool
    facebook_on_created: bool


class Email(BaseModel):
    email_from_name: str
    email_bcc: str
    email_on_pause: bool
    email_smtp_password: str
    email_tls: bool
    email_smtp_port: str
    email_on_watched: bool
    email_smtp_server: str
    email_on_intdown: bool
    email_on_concurrent: bool
    email_on_intup: bool
    email_enabled: bool
    email_on_buffer: bool
    email_on_resume: bool
    email_smtp_user: str
    email_cc: str
    email_on_newdevice: bool
    email_on_stop: bool
    email_on_extdown: bool
    email_html_support: bool
    email_on_extup: bool
    email_on_created: bool
    email_on_pmsupdate: bool
    email_to: str
    email_from: str
    email_on_play: bool


class OSXNotify(BaseModel):
    osx_notify_on_intdown: bool
    osx_notify_on_buffer: bool
    osx_notify_app: str
    osx_notify_on_created: bool
    osx_notify_on_pmsupdate: bool
    osx_notify_on_stop: bool
    osx_notify_enabled: bool
    osx_notify_on_intup: bool
    osx_notify_on_watched: bool
    osx_notify_on_pause: bool
    osx_notify_on_concurrent: bool
    osx_notify_on_newdevice: bool
    osx_notify_on_play: bool
    osx_notify_on_extdown: bool
    osx_notify_on_extup: bool
    osx_notify_on_resume: bool


class PlexWatch(BaseModel):
    grouping_user_history: bool
    plexwatch_database: str
    grouping_global_history: bool
    grouping_charts: bool


class Pushover(BaseModel):
    pushover_enabled: bool
    pushover_on_extup: bool
    pushover_on_intup: bool
    pushover_on_buffer: bool
    pushover_html_support: bool
    pushover_keys: str
    pushover_incl_url: bool
    pushover_on_pause: bool
    pushover_on_play: bool
    pushover_on_stop: bool
    pushover_apitoken: str
    pushover_incl_pmslink: bool
    pushover_on_pmsupdate: bool
    pushover_on_extdown: bool
    pushover_priority: bool
    pushover_on_intdown: bool
    pushover_on_newdevice: bool
    pushover_sound: str
    pushover_on_created: bool
    pushover_on_resume: bool
    pushover_on_concurrent: bool
    pushover_on_watched: bool


class Telegram(BaseModel):
    telegram_on_buffer: bool
    telegram_bot_token: str
    telegram_incl_poster: bool
    telegram_on_resume: bool
    telegram_on_pmsupdate: bool
    telegram_html_support: bool
    telegram_on_created: bool
    telegram_incl_subject: bool
    telegram_disable_web_preview: bool
    telegram_enabled: bool
    telegram_on_concurrent: bool
    telegram_on_intdown: bool
    telegram_on_extdown: bool
    telegram_on_pause: bool
    telegram_on_newdevice: bool
    telegram_on_watched: bool
    telegram_on_stop: bool
    telegram_on_play: bool
    telegram_on_extup: bool
    telegram_chat_id: str
    telegram_on_intup: bool


class Twitter(BaseModel):
    twitter_on_resume: bool
    twitter_on_pmsupdate: bool
    twitter_on_buffer: bool
    twitter_on_concurrent: bool
    twitter_enabled: bool
    twitter_on_watched: bool
    twitter_consumer_secret: str
    twitter_on_extup: bool
    twitter_on_intdown: bool
    twitter_on_intup: bool
    twitter_access_token_secret: str
    twitter_on_newdevice: bool
    twitter_on_stop: bool
    twitter_consumer_key: str
    twitter_access_token: str
    twitter_incl_subject: bool
    twitter_on_extdown: bool
    twitter_on_pause: bool
    twitter_on_play: bool
    twitter_incl_poster: bool
    twitter_on_created: bool


class Plex(BaseModel):
    plex_on_created: bool
    plex_on_concurrent: bool
    plex_client_host: str
    plex_on_stop: bool
    plex_on_resume: bool
    plex_on_watched: bool
    plex_on_play: bool
    plex_on_extdown: bool
    plex_on_intdown: bool
    plex_on_newdevice: bool
    plex_enabled: bool
    plex_on_buffer: bool
    plex_on_intup: bool
    plex_on_pmsupdate: bool
    plex_username: str
    plex_on_pause: bool
    plex_password: str
    plex_on_extup: bool


class Join(BaseModel):
    join_on_concurrent: bool
    join_on_newdevice: bool
    join_deviceid: str
    join_on_play: bool
    join_on_watched: bool
    join_on_resume: bool
    join_on_created: bool
    join_on_extdown: bool
    join_on_intup: bool
    join_on_buffer: bool
    join_incl_subject: bool
    join_enabled: bool
    join_on_pause: bool
    join_apikey: str
    join_on_pmsupdate: bool
    join_on_intdown: bool
    join_on_extup: bool
    join_on_stop: bool


class XBMC(BaseModel):
    xbmc_password: str
    xbmc_on_play: bool
    xbmc_on_pause: bool
    xbmc_username: str
    xbmc_on_extup: bool
    xbmc_on_watched: bool
    xbmc_on_buffer: bool
    xbmc_enabled: bool
    xbmc_host: str
    xbmc_on_created: bool
    xbmc_on_intup: bool
    xbmc_on_extdown: bool
    xbmc_on_pmsupdate: bool
    xbmc_on_stop: bool
    xbmc_on_newdevice: bool
    xbmc_on_resume: bool
    xbmc_on_intdown: bool
    xbmc_on_concurrent: bool


class Browser(BaseModel):
    browser_on_intdown: bool
    browser_on_newdevice: bool
    browser_on_pmsupdate: bool
    browser_on_intup: bool
    browser_on_buffer: bool
    browser_auto_hide_delay: str
    browser_on_created: bool
    browser_on_pause: bool
    browser_on_stop: bool
    browser_on_play: bool
    browser_on_watched: bool
    browser_on_extdown: bool
    browser_on_extup: bool
    browser_on_resume: bool
    browser_on_concurrent: bool
    browser_enabled: bool


class Newsletter(BaseModel):
    newsletter_dir: str
    newsletter_templates: str
    newsletter_self_hosted: bool
    newsletter_static_url: bool
    newsletter_inline_styles: bool
    newsletter_password: str
    newsletter_custom_dir: str
    newsletter_auth: bool


class Cloudinary(BaseModel):
    cloudinary_api_key: str
    cloudinary_cloud_name: str
    cloudinary_api_secret: str


class Data(BaseModel):
    IFTTT: IFTTT
    Growl: Growl
    PMS: PMS
    Monitoring: Monitoring
    General: General
    Slack: Slack
    Boxcar: Boxcar
    PushBullet: PushBullet
    Scripts: Scripts
    NMA: NMA
    Hipchat: Hipchat
    Pushalot: Pushalot
    Prowl: Prowl
    Advanced: Advanced
    Facebook: Facebook
    Email: Email
    OSX_Notify: OSXNotify
    PlexWatch: PlexWatch
    Pushover: Pushover
    Telegram: Telegram
    Twitter: Twitter
    Plex: Plex
    Join: Join
    XBMC: XBMC
    Browser: Browser
    Newsletter: Newsletter
    Cloudinary: Cloudinary


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



import sys
from functools import wraps

from tautulli.utils import _success_result, _get_response_data


def raw_api_bool(func):
    @wraps(func)
    def wrapper(self, *args, **kwargs) -> bool:
        try:
            method = getattr(self._raw_api, func.__name__)
            return method(*args, **kwargs)
        except AttributeError:
            return False

    return wrapper


def make_property_object(func):
    @wraps(func)
    def wrapper(self, *args, **kwargs) -> object:
        try:
            data = getattr(self._raw_api, func.__name__)
            if not data:
                return None
            class_name = globals()[func(self)]
            if type(data) == list:
                return [class_name(**item) for item in data]
            else:
                return class_name(**data)
        except AttributeError:
            return None

    return wrapper


def make_object(func):
    @wraps(func)
    def wrapper(self, *args, **kwargs) -> object:
        try:
            method = getattr(self._raw_api, func.__name__)
            data = method(*args, **kwargs)
            if not data:
                return None
            class_name = getattr(sys.modules["tautulli.models"], func(self))
            if type(data) == list:
                return [class_name(**item) for item in data]
            else:
                return class_name(**data)
        except AttributeError:
            return None

    return wrapper


def set_and_forget(func):
    @wraps(func)
    def wrapper(self, *args, **kwargs) -> bool:
        """
        Return if the ['response']['result'] part of the JSON response == 'success'
        :rtype: bool
        """
        command, params = func(self, *args, **kwargs)
        if not command:
            return False
        json_data = self._get_json(command=command, params=params)
        return _success_result(json_data=json_data)

    return wrapper


def raw_json(func):
    @wraps(func)
    def wrapper(self, *args, **kwargs) -> dict:
        """
        Return the ['response']['data'] part of the JSON response
        :rtype: dict
        """
        command, params = func(self, *args, **kwargs)
        if not command:
            return {}
        json_data = self._get_json(command=command, params=params)
        return _get_response_data(json_data=json_data)

    return wrapper



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:59:53+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Data(BaseModel):
    row_id: int
    user_id: int
    username: str
    friendly_name: str
    user_thumb: str
    email: str
    is_active: int
    is_admin: str
    is_home_user: int
    is_allow_sync: int
    is_restricted: int
    do_notify: int
    keep_history: int
    allow_guest: int
    deleted_user: int
    shared_libraries: List


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:34:08+00:00

from __future__ import annotations

from typing import Any

from pydantic import BaseModel


class Data(BaseModel):
    code: str
    country: str
    region: str
    city: str
    postal_code: str
    timezone: str
    latitude: float
    longitude: float
    continent: Any
    accuracy: Any


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:22:02+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    httpsRequired: str
    clientIdentifier: str
    label: str
    ip: str
    port: str
    uri: str
    local: str
    value: str
    is_cloud: bool


class Response(BaseModel):
    result: str
    message: Any
    data: List[Datum]


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:38:24+00:00

from __future__ import annotations

from typing import Any, List, Optional

from pydantic import BaseModel


class Datum(BaseModel):
    video_resolution: str
    audio_channels: str
    container: str
    thumb: str
    media_index: str
    title: str
    bitrate: str
    video_codec: str
    section_type: str
    section_id: int
    added_at: str
    sort_title: str
    file_size: str
    parent_rating_key: str
    audio_codec: str
    year: str
    media_type: str
    parent_media_index: str
    grandparent_rating_key: str
    rating_key: str
    video_framerate: str
    last_played: Optional[int]
    play_count: Optional[int]


class Data(BaseModel):
    recordsFiltered: int
    recordsTotal: int
    data: List[Datum]
    draw: int
    filtered_file_size: int
    total_file_size: int


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:50:23+00:00

from __future__ import annotations

from typing import Any

from pydantic import BaseModel, Field


class Field0(BaseModel):
    rating_key: int


class Data(BaseModel):
    field_0: Field0 = Field(..., alias='0')


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:44:54+00:00

from __future__ import annotations

from typing import List, Optional, Union

from pydantic import BaseModel, Field


class Config(BaseModel):
    custom_cron: int
    time_frame: int
    time_frame_units: str
    formatted: int
    threaded: int
    notifier_id: int
    filename: str
    save_only: int
    incl_libraries: List[str]


class EmailConfig(BaseModel):
    from_name: str
    from_: str = Field(..., alias='from')
    to: List[str]
    cc: List
    bcc: List
    smtp_server: str
    smtp_port: int
    smtp_user: str
    smtp_password: str
    tls: int
    html_support: int
    notifier_id: int


class MovieLibrary(BaseModel):
    value: int
    text: str


class TVShowLibrary(BaseModel):
    value: int
    text: str


class MusicLibrary(BaseModel):
    value: int
    text: str


class OtherVideoLibrary(BaseModel):
    value: int
    text: str


class SelectOptions(BaseModel):
    Movie_Libraries: List[MovieLibrary] = Field(..., alias='Movie Libraries')
    TV_Show_Libraries: List[TVShowLibrary] = Field(..., alias='TV Show Libraries')
    Music_Libraries: List[MusicLibrary] = Field(..., alias='Music Libraries')
    Other_Video_Libraries: List[OtherVideoLibrary] = Field(
        ..., alias='Other Video Libraries'
    )


class ConfigOption(BaseModel):
    label: str
    value: List[str]
    description: str
    name: str
    input_type: str
    select_options: SelectOptions


class SelectOption(BaseModel):
    value: str
    text: str


class EmailConfigOption(BaseModel):
    label: str
    value: Union[Union[int, str], List[str]]
    name: str
    description: str
    input_type: str
    select_options: Optional[List[SelectOption]] = None


class Data(BaseModel):
    id: int
    agent_id: int
    agent_name: str
    agent_label: str
    friendly_name: str
    cron: str
    active: int
    id_name: str
    subject: str
    body: str
    config: Config
    email_config: EmailConfig
    config_options: List[ConfigOption]
    email_config_options: List[EmailConfigOption]


class Response(BaseModel):
    result: str
    message: str
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T05:03:28+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    browser: str
    friendly_name: str
    host: str
    ip_address: str
    os: str
    timestamp: int
    user: str
    user_agent: str
    user_group: str
    user_id: int


class Data(BaseModel):
    draw: int
    recordsTotal: int
    recordsFiltered: int
    data: List[Datum]


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:24:52+00:00

from __future__ import annotations

from typing import Any, List, Optional

from pydantic import BaseModel


class Datum(BaseModel):
    row_id: int
    user_id: int
    username: str
    friendly_name: str
    thumb: Optional[str]
    email: Optional[str]
    is_active: int
    is_admin: int
    is_home_user: Optional[int]
    is_allow_sync: Optional[int]
    is_restricted: Optional[int]
    do_notify: int
    keep_history: int
    allow_guest: int
    server_token: Optional[str]
    shared_libraries: Optional[str]
    filter_all: Optional[str]
    filter_movies: Optional[str]
    filter_tv: Optional[str]
    filter_music: Optional[str]
    filter_photos: Optional[str]


class Response(BaseModel):
    result: str
    message: Any
    data: List[Datum]


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T01:23:27+00:00

from __future__ import annotations

from typing import Any, List, Optional

from pydantic import BaseModel


class Session(BaseModel):
    session_key: str
    media_type: str
    view_offset: str
    progress_percent: str
    quality_profile: str
    synced_version_profile: str
    optimized_version_profile: str
    user: str
    channel_stream: int
    section_id: str
    library_name: str
    rating_key: str
    parent_rating_key: str
    grandparent_rating_key: str
    title: str
    parent_title: str
    grandparent_title: str
    original_title: str
    sort_title: str
    media_index: str
    parent_media_index: str
    studio: str
    content_rating: str
    summary: str
    tagline: str
    rating: str
    rating_image: str
    audience_rating: str
    audience_rating_image: str
    user_rating: str
    duration: str
    year: str
    thumb: str
    parent_thumb: str
    grandparent_thumb: str
    art: str
    banner: str
    originally_available_at: str
    added_at: str
    updated_at: str
    last_viewed_at: str
    guid: str
    parent_guid: str
    grandparent_guid: str
    directors: List
    writers: List
    actors: List
    genres: List[str]
    labels: List
    collections: List
    guids: List
    full_title: str
    children_count: int
    live: int
    id: str
    container: str
    bitrate: str
    height: str
    width: str
    aspect_ratio: str
    video_codec: str
    video_resolution: str
    video_full_resolution: str
    video_framerate: str
    video_profile: str
    audio_codec: str
    audio_channels: str
    audio_channel_layout: str
    audio_profile: str
    optimized_version: int
    channel_call_sign: str
    channel_identifier: str
    channel_thumb: str
    file: str
    file_size: str
    indexes: int
    selected: int
    type: str
    video_codec_level: str
    video_bitrate: str
    video_bit_depth: str
    video_chroma_subsampling: str
    video_color_primaries: str
    video_color_range: str
    video_color_space: str
    video_color_trc: str
    video_frame_rate: str
    video_ref_frames: str
    video_height: str
    video_width: str
    video_language: str
    video_language_code: str
    video_scan_type: str
    audio_bitrate: str
    audio_bitrate_mode: str
    audio_sample_rate: str
    audio_language: str
    audio_language_code: str
    subtitle_codec: str
    subtitle_container: str
    subtitle_format: str
    subtitle_forced: int
    subtitle_location: str
    subtitle_language: str
    subtitle_language_code: str
    row_id: int
    user_id: int
    username: str
    friendly_name: str
    user_thumb: str
    email: str
    is_active: int
    is_admin: int
    is_home_user: int
    is_allow_sync: int
    is_restricted: int
    do_notify: int
    keep_history: int
    deleted_user: int
    allow_guest: int
    shared_libraries: List[str]
    ip_address: str
    ip_address_public: str
    device: str
    platform: str
    platform_name: str
    platform_version: str
    product: str
    product_version: str
    profile: str
    player: str
    machine_id: str
    state: str
    local: int
    relayed: int
    secure: int
    session_id: str
    bandwidth: str
    location: str
    transcode_key: str
    transcode_throttled: int
    transcode_progress: int
    transcode_speed: str
    transcode_audio_channels: str
    transcode_audio_codec: str
    transcode_video_codec: str
    transcode_width: str
    transcode_height: str
    transcode_container: str
    transcode_protocol: str
    transcode_hw_requested: int
    transcode_hw_decode: str
    transcode_hw_decode_title: str
    transcode_hw_encode: str
    transcode_hw_encode_title: str
    transcode_hw_full_pipeline: int
    audio_decision: str
    video_decision: str
    subtitle_decision: str
    throttled: str
    transcode_hw_decoding: int
    transcode_hw_encoding: int
    stream_container: str
    stream_bitrate: str
    stream_aspect_ratio: str
    stream_audio_codec: str
    stream_audio_channels: str
    stream_audio_channel_layout: str
    stream_video_codec: str
    stream_video_framerate: str
    stream_video_resolution: str
    stream_video_height: str
    stream_video_width: str
    stream_duration: str
    stream_container_decision: str
    optimized_version_title: str
    synced_version: int
    live_uuid: str
    bif_thumb: str
    subtitles: int
    transcode_decision: str
    container_decision: str
    stream_video_full_resolution: Optional[str] = None
    video_dynamic_range: str
    stream_video_dynamic_range: str
    stream_video_bitrate: str
    stream_video_bit_depth: str
    stream_video_chroma_subsampling: str
    stream_video_color_primaries: str
    stream_video_color_range: str
    stream_video_color_space: str
    stream_video_color_trc: str
    stream_video_codec_level: str
    stream_video_ref_frames: str
    stream_video_language: str
    stream_video_language_code: str
    stream_video_scan_type: str
    stream_video_decision: str
    stream_audio_bitrate: str
    stream_audio_bitrate_mode: str
    stream_audio_sample_rate: str
    stream_audio_channel_layout_: str
    stream_audio_language: str
    stream_audio_language_code: str
    stream_audio_decision: str
    stream_subtitle_codec: str
    stream_subtitle_container: str
    stream_subtitle_format: str
    stream_subtitle_forced: int
    stream_subtitle_location: str
    stream_subtitle_language: str
    stream_subtitle_language_code: str
    stream_subtitle_decision: str
    stream_subtitle_transient: int


class Data(BaseModel):
    stream_count: str
    sessions: List[Session]
    stream_count_direct_play: int
    stream_count_direct_stream: int
    stream_count_transcode: int
    total_bandwidth: int
    lan_bandwidth: int
    wan_bandwidth: int


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:56:39+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    audio_bitrate: str
    client_id: str
    content_type: str
    device_name: str
    failure: str
    item_complete_count: str
    item_count: str
    item_downloaded_count: str
    item_downloaded_percent_complete: int
    metadata_type: str
    photo_quality: str
    platform: str
    rating_key: str
    root_title: str
    state: str
    sync_id: str
    sync_title: str
    total_size: str
    user: str
    user_id: str
    username: str
    video_bitrate: str
    video_quality: str


class Response(BaseModel):
    result: str
    message: Any
    data: List[Datum]


class Model(BaseModel):
    response: Response



import os

"""
from typing import Union

from tautulli import models

class TautulliObject:
    def __init__(self, data: dict):
        self._data = data


class Docs(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Activity(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class DateFormats(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class LibraryNames(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Newsletters(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class NotifierParameters(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class PMSUpdate(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class ServerIdentity(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class ServerInfo(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class ServerList(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class ServersInfo(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class UserNames(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Users(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class UpdateCheck(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class CollectionsTable(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class ExportFields(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class GeoIPLookup(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class History(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class HomeStats(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Library(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Libraries(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class LibrariesTable(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class LibraryMediaInfo(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class LibraryUserStats(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class LibraryWatchTimeStats(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Logs(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Metadata(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class NewRatingKeys(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class NewsletterConfig(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class NewsletterLog(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class NotificationLog(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class NotifierConfig(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Notifiers(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class OldRatingKeys(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class PlaylistsTable(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class PlexLog(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class RecentlyAdded(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class ServerID(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class Settings(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class StreamData(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class SyncedItems(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class User(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class UserIPs(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class UserLogins(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class UserPlayerStats(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class UserWatchTimeStats(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class UsersTable(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class WHOISLookup(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class RegisteredDevice(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class SearchResults(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)


class SQLResults(TautulliObject):
    def __init__(self, data: dict):
        super().__init__(data=data)
"""


# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:36:07+00:00

from __future__ import annotations

from typing import Any, List, Optional

from pydantic import BaseModel


class Datum(BaseModel):
    section_id: str
    section_name: str
    section_type: str
    agent: str
    thumb: str
    art: str
    count: str
    is_active: int
    parent_count: Optional[str] = None
    child_count: Optional[str] = None


class Response(BaseModel):
    result: str
    message: Any
    data: List[Datum]


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T05:02:13+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    friendly_name: str
    guid: str
    id: int
    ip_address: str
    last_played: str
    last_seen: int
    first_seen: int
    live: int
    media_index: int
    media_type: str
    originally_available_at: str
    parent_media_index: int
    parent_title: str
    platform: str
    play_count: int
    player: str
    rating_key: int
    thumb: str
    transcode_decision: str
    user_id: int
    year: int


class Data(BaseModel):
    draw: int
    recordsTotal: int
    recordsFiltered: int
    data: List[Datum]


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:45:45+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    id: int
    timestamp: int
    session_key: int
    rating_key: int
    user_id: int
    user: str
    notifier_id: int
    agent_id: int
    agent_name: str
    notify_action: str
    subject_text: str
    body_text: str
    success: int


class Data(BaseModel):
    recordsFiltered: int
    recordsTotal: int
    data: List[Datum]
    draw: int


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:51:38+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Data(BaseModel):
    data: List


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:29:06+00:00

from __future__ import annotations

from typing import Any, Dict

from pydantic import BaseModel


class Response(BaseModel):
    result: str
    message: str
    data: Dict[str, Any]


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:35:02+00:00

from __future__ import annotations

from typing import Any, List, Union

from pydantic import BaseModel


class Datum(BaseModel):
    reference_id: int
    row_id: int
    id: int
    date: int
    started: int
    stopped: int
    duration: int
    paused_counter: int
    user_id: int
    user: str
    friendly_name: str
    platform: str
    product: str
    player: str
    ip_address: str
    live: int
    machine_id: str
    media_type: str
    rating_key: int
    parent_rating_key: Union[int, str]
    grandparent_rating_key: Union[int, str]
    full_title: str
    title: str
    parent_title: str
    grandparent_title: str
    original_title: str
    year: Union[int, str]
    media_index: Union[int, str]
    parent_media_index: Union[int, str]
    thumb: str
    originally_available_at: str
    guid: str
    transcode_decision: str
    percent_complete: int
    watched_status: float
    group_count: int
    group_ids: str
    state: Any
    session_key: Any


class Data(BaseModel):
    recordsFiltered: int
    recordsTotal: int
    data: List[Datum]
    draw: int
    filter_duration: str
    total_duration: str


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T01:28:24+00:00

from __future__ import annotations

from typing import Any

from pydantic import BaseModel


class Data(BaseModel):
    add_newsletter_config: str
    add_notifier_config: str
    arnold: str
    backup_config: str
    backup_db: str
    delete_all_library_history: str
    delete_all_user_history: str
    delete_cache: str
    delete_export: str
    delete_history: str
    delete_hosted_images: str
    delete_image_cache: str
    delete_library: str
    delete_login_log: str
    delete_lookup_info: str
    delete_media_info_cache: str
    delete_mobile_device: str
    delete_newsletter: str
    delete_newsletter_log: str
    delete_notification_log: str
    delete_notifier: str
    delete_recently_added: str
    delete_synced_item: str
    delete_temp_sessions: str
    delete_user: str
    docs: str
    docs_md: str
    download_config: str
    download_database: str
    download_export: str
    download_log: str
    download_plex_log: str
    edit_library: str
    edit_user: str
    export_metadata: str
    get_activity: str
    get_apikey: str
    get_collections_table: str
    get_date_formats: str
    get_export_fields: str
    get_exports_table: str
    get_geoip_lookup: str
    get_history: str
    get_home_stats: str
    get_libraries: str
    get_libraries_table: str
    get_library: str
    get_library_media_info: str
    get_library_names: str
    get_library_user_stats: str
    get_library_watch_time_stats: str
    get_logs: str
    get_metadata: str
    get_new_rating_keys: str
    get_newsletter_config: str
    get_newsletter_log: str
    get_newsletters: str
    get_notification_log: str
    get_notifier_config: str
    get_notifier_parameters: str
    get_notifiers: str
    get_old_rating_keys: str
    get_playlists_table: str
    get_plays_by_date: str
    get_plays_by_dayofweek: str
    get_plays_by_hourofday: str
    get_plays_by_source_resolution: str
    get_plays_by_stream_resolution: str
    get_plays_by_stream_type: str
    get_plays_by_top_10_platforms: str
    get_plays_by_top_10_users: str
    get_plays_per_month: str
    get_plex_log: str
    get_pms_token: str
    get_pms_update: str
    get_recently_added: str
    get_server_friendly_name: str
    get_server_id: str
    get_server_identity: str
    get_server_info: str
    get_server_list: str
    get_server_pref: str
    get_servers_info: str
    get_settings: str
    get_stream_data: str
    get_stream_type_by_top_10_platforms: str
    get_stream_type_by_top_10_users: str
    get_synced_items: str
    get_user: str
    get_user_ips: str
    get_user_logins: str
    get_user_names: str
    get_user_player_stats: str
    get_user_watch_time_stats: str
    get_users: str
    get_users_table: str
    get_whois_lookup: str
    import_config: str
    import_database: str
    notify: str
    notify_newsletter: str
    notify_recently_added: str
    pms_image_proxy: str
    refresh_libraries_list: str
    refresh_users_list: str
    register_device: str
    restart: str
    search: str
    server_status: str
    set_mobile_device_config: str
    set_newsletter_config: str
    set_notifier_config: str
    sql: str
    status: str
    terminate_session: str
    undelete_library: str
    undelete_user: str
    update: str
    update_check: str
    update_metadata_details: str


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:27:48+00:00

from __future__ import annotations

from typing import Any, List, Optional

from pydantic import BaseModel


class Datum(BaseModel):
    addedAt: str
    art: Any
    childCount: int
    collectionMode: int
    collectionSort: int
    contentRating: Optional[str]
    guid: str
    librarySectionID: str
    librarySectionTitle: str
    maxYear: Optional[int]
    minYear: Optional[int]
    ratingKey: int
    subtype: str
    summary: str
    thumb: str
    title: str
    titleSort: str
    type: str
    updatedAt: str


class Data(BaseModel):
    recordsFiltered: int
    recordsTotal: int
    data: List[Datum]
    draw: int


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



from tautulli.models.activity import Data as Activity
from tautulli.models.docs import Data as Docs
from tautulli.models.dateformats import Data as DateFormats
from tautulli.models.librarynames import Data as LibraryNames
from tautulli.models.newsletters import Datum as Newsletters
from tautulli.models.notifierparameters import Datum as NotifierParameters
from tautulli.models.pmsupdate import Data as PMSUpdate
from tautulli.models.serveridentity import Data as ServerIdentity
from tautulli.models.serverinfo import Data as ServerInfo
from tautulli.models.serverlist import Datum as ServerList
from tautulli.models.serversinfo import Datum as ServersInfo
from tautulli.models.usernames import Datum as UserNames
from tautulli.models.users import Datum as Users
from tautulli.models.updatecheck import Data as UpdateCheck
from tautulli.models.collectionstable import Data as CollectionsTable
from tautulli.models.activity import Data as ExportFields # TODO: Need fix
from tautulli.models.geoiplookup import Data as GeoIPLookup
from tautulli.models.history import Data as History
from tautulli.models.homestats import Datum as HomeStats
from tautulli.models.library import Data as Library
from tautulli.models.libraries import Datum as Libraries
from tautulli.models.librariestable import Data as LibrariesTable
from tautulli.models.librarymediainfo import Data as LibraryMediaInfo
from tautulli.models.libraryuserstats import Datum as LibraryUserStats
from tautulli.models.librarywatchtimestats import Datum as LibraryWatchTimeStats
from tautulli.models.logs import Datum as Logs
from tautulli.models.metadata import Data as Metadata
from tautulli.models.newratingkeys import Data as NewRatingKeys
from tautulli.models.newsletterconfig import Data as NewsletterConfig
from tautulli.models.newsletterlog import Data as NewsletterLog
from tautulli.models.notificationlog import Data as NotificationLog
from tautulli.models.activity import Data as NotifierConfig # TODO: Revisit, generator is failing
from tautulli.models.notifiers import Datum as Notifiers
from tautulli.models.oldratingkeys import Data as OldRatingKeys
from tautulli.models.playliststable import Data as PlaylistsTable
from tautulli.models.plexlog import Data as PlexLog
from tautulli.models.recentlyadded import Data as RecentlyAdded
from tautulli.models.serverid import Data as ServerID
from tautulli.models.settings import Data as Settings
from tautulli.models.streamdata import Data as StreamData
from tautulli.models.synceditems import Datum as SyncedItems
from tautulli.models.user import Data as User
from tautulli.models.userips import Data as UserIPs
from tautulli.models.userlogins import Data as UserLogins
from tautulli.models.userplayerstats import Datum as UserPlayerStats
from tautulli.models.userwatchtimestats import Datum as UserWatchTimeStats
from tautulli.models.userstable import Data as UsersTable
from tautulli.models.whoislookup import Data as WHOISLookup
from tautulli.models.registereddevice import Data as RegisteredDevice
from tautulli.models.searchresults import Data as SearchResults
from tautulli.models.activity import Data as SQLResults  # TODO: Need to implement



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T05:04:32+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    platform_type: str
    player_name: str
    result_id: int
    total_plays: int


class Response(BaseModel):
    result: str
    message: Any
    data: List[Datum]


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:51:11+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    addedAt: str
    composite: str
    duration: int
    guid: str
    leafCount: int
    librarySectionID: str
    playlistType: str
    ratingKey: int
    smart: bool
    summary: str
    title: str
    type: str
    updatedAt: str
    userID: Any


class Data(BaseModel):
    recordsFiltered: int
    recordsTotal: int
    data: List[Datum]
    draw: int


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:37:01+00:00

from __future__ import annotations

from typing import Any

from pydantic import BaseModel


class Data(BaseModel):
    row_id: int
    server_id: str
    section_id: int
    section_name: str
    section_type: str
    library_thumb: str
    library_art: str
    count: int
    parent_count: Any
    child_count: Any
    is_active: int
    do_notify: int
    do_notify_created: int
    keep_history: int
    deleted_section: int


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T04:40:08+00:00

from __future__ import annotations

from typing import Any, List

from pydantic import BaseModel


class Datum(BaseModel):
    time: str
    loglevel: str
    msg: str
    thread: str


class Response(BaseModel):
    result: str
    message: Any
    data: List[Datum]


class Model(BaseModel):
    response: Response



# generated by datamodel-codegen:
#   filename:  data.json
#   timestamp: 2021-01-27T05:05:45+00:00

from __future__ import annotations

from typing import Any, List, Optional, Union

from pydantic import BaseModel


class Datum(BaseModel):
    row_id: int
    user_id: int
    username: str
    friendly_name: str
    user_thumb: str
    plays: int
    duration: int
    last_seen: Optional[int]
    last_played: Optional[str]
    history_row_id: Optional[int]
    ip_address: Optional[str]
    platform: Optional[str]
    player: Optional[str]
    rating_key: Optional[int]
    media_type: Optional[str]
    thumb: Optional[str]
    parent_title: Optional[str]
    year: Optional[int]
    media_index: Optional[Union[int, str]]
    parent_media_index: Optional[Union[int, str]]
    live: Optional[int]
    originally_available_at: Optional[str]
    guid: Optional[str]
    transcode_decision: Optional[str]
    do_notify: str
    keep_history: str
    allow_guest: str
    is_active: int


class Data(BaseModel):
    recordsFiltered: int
    recordsTotal: int
    data: List[Datum]
    draw: int


class Response(BaseModel):
    result: str
    message: Any
    data: Data


class Model(BaseModel):
    response: Response
